﻿using System;
using System.Collections.Concurrent;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.FlowEngine.Definitions;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.FlowEngine.WfModules;

/// <summary>
/// 工作流业务模块
/// </summary>
public class WorkflowModule : CreationEntity
{
    public WorkflowModule()
    {

    }

    public WorkflowModule(string code, string name, string remark = "")
    {
        this.Code = code;
        this.Name = name;
        this.Remark = remark;
    }

    /// <summary>
    /// WorkflowModuleConsts约定code
    /// </summary>
    public string Code { get; set; }

    public string Name { get; set; }

    public string Remark { get; set; } = string.Empty;

    /// <summary>
    /// 流程模板Id
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? DefinitionId { get; set; }

    [Navigate(NavigateType.OneToOne, nameof(DefinitionId))]
    public Definition? Definition { get; set; }

    ///// <summary>
    ///// 模板名称（冗余）
    ///// </summary>
    //[SugarColumn(IsNullable = true)]
    //public string? DefinitionName { get; set; }

    ///// <summary>
    ///// 模板编码（冗余）
    ///// </summary>
    //[SugarColumn(IsNullable = true)]
    //public string? DefinitionCode { get; set; }

    ///// <summary>
    ///// 模板版本号（冗余）
    ///// </summary>
    //public int? DefinitionVersion { get; set; }
}

public class WorkflowModuleConsts
{
    /// <summary>
    /// 工单办理
    /// </summary>
    public const string OrderManage = "OrderManage";

    /// <summary>
    /// 新增知识审批
    /// </summary>
    public const string KnowledgeAdd = "KnowledgeAdd";

    /// <summary>
    /// 知识更新
    /// </summary>
    public const string KnowledgeUpdate = "KnowledgeUpdate";

    /// <summary>
    /// 知识删除
    /// </summary>
    public const string KnowledgeDelete = "KnowledgeDelete";

    /// <summary>
    /// 分机小休申请
    /// </summary>
    public const string TelRestApply = "TelRestApply";



    public static List<WorkflowModule> AllModules =>
        new()
        {
            new(OrderManage, "工单办理"),
            new(KnowledgeAdd, "新增知识审批"),
            new(KnowledgeUpdate, "知识更新"),
            new(KnowledgeDelete, "知识删除"),
            new(TelRestApply, "分机小休申请"),
        };
}